@@ -6,6 +6,16 @@ use parent qw(Plack::Middleware);
 use Scalar::Util qw(blessed);
 use Plack::Util;
 
+sub wrap {
+    my($self, $app) = @_;
+
+    unless (ref $app eq 'CODE' or overload::Method($app, '&{}')) {
+        Carp::croak("PSGI app should be a code reference: $app");
+    }
+
+    $self->SUPER::wrap($app);
+}
+
 sub call {
     my $self = shift;
     my $env = shift;
@@ -79,7 +89,7 @@ sub validate_res {
     my $croak = $streaming ? \&Carp::confess : \&Carp::croak;
 
     unless (ref($res) and ref($res) eq 'ARRAY' || ref($res) eq 'CODE') {
-        $croak->('response should be arrayref or coderef');
+        $croak->('response should be array ref or code ref');
     }
 
     if (ref $res eq 'CODE') {
@@ -137,6 +147,9 @@ and response environment formats. You are strongly suggested to use
 this middleware when you develop a new framework adapter or a new PSGI
 web server that implements the PSGI interface.
 
+This middleware is enabled by default when you run plackup or other
+launcher tools with the default environment I<development> value.
+
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
