@@ -105,7 +105,7 @@ sub _load_sandbox {
     my $_package = $_file;
     $_package =~ s/([^A-Za-z0-9_])/sprintf("_%2x", unpack("C", $1))/eg;
 
-    eval "package Plack::Sandbox::$_package; do(\$_file)";
+    eval "package Plack::Sandbox::$_package; do(\$_file) or die(\$\@ || \$!)";
 }
 
 sub load_psgi {
